@@ -1,10 +1,12 @@
 # flake8: noqa
-__version__ = '4.0.0'
+__version__ = "4.2.1"
 
 from .vegalite import *
 from . import examples
 
+
 def load_ipython_extension(ipython):
     from ._magics import vega, vegalite
-    ipython.register_magic_function(vega, 'cell')
-    ipython.register_magic_function(vegalite, 'cell')
+
+    ipython.register_magic_function(vega, "cell")
+    ipython.register_magic_function(vegalite, "cell")
